==> lowcode-editor-skeleton-2.0.5.tgz: package/es/components/settings/components/array-advance-table/side-content/index.js <==
import _Dropdown from "antd/es/dropdown";
import _Drawer from "antd/es/drawer";
import _Button from "antd/es/button";
import _Collapse from "antd/es/collapse";
import _extends from "@babel/runtime/helpers/extends";
import _Card from "antd/es/card";
import _Empty from "antd/es/empty";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/objectWithoutPropertiesLoose";
var _excluded = ["children"],
  _excluded2 = ["setOpen"],
  _excluded3 = ["onClick"];
import { observer, RecursionField, Schema, useFieldSchema } from '@formily/react';
import { toArr } from '@formily/shared';
import cls from 'classnames';
import { createContext, useContext, useEffect, useState } from 'react';
import useStyle, { useSideDrawerStyle } from './style';
import { usePrefixCls } from '@formily/antd-v5/lib/__builtins__';
import { ArrayBase } from '@formily/antd-v5';
import { isSidePanelComponent } from '../common';
import { get, isEmpty, set } from 'lodash';
import { CloseOutlined } from '@ant-design/icons';
import { useSubSlotRef } from '../../../context';
import { useSelected } from '../../../../../hooks';
var range = function range(count) {
  return Array.from({
    length: count
  }).map(function (_, i) {
    return i;
  });
};
var takeDefaultActiveKeys = function takeDefaultActiveKeys(dataSourceLength, defaultOpenPanelCount) {
  if (dataSourceLength < defaultOpenPanelCount) return range(dataSourceLength);
  return range(defaultOpenPanelCount);
};
var insertActiveKeys = function insertActiveKeys(activeKeys, index) {
  if (activeKeys.length <= index) return activeKeys.concat(index);
  return activeKeys.reduce(function (buf, key) {
    if (key < index) return buf.concat(key);
    if (key === index) return buf.concat([key, key + 1]);
    return buf.concat(key + 1);
  }, []);
};
export var SideBaseContext = /*#__PURE__*/createContext(null);
export var RulePathContext = /*#__PURE__*/createContext(null);
export var SideItemContext = /*#__PURE__*/createContext(null);
var SideContentItem = function SideContentItem(_ref) {
  var children = _ref.children,
    props = _objectWithoutPropertiesLoose(_ref, _excluded);
  return /*#__PURE__*/React.createElement(SideItemContext.Provider, {
    value: props
  }, children);
};
var SideContentDrawerContext = observer(function (_ref2) {
  var _props$defaultOpenPan;
  var setOpen = _ref2.setOpen,
    props = _objectWithoutPropertiesLoose(_ref2, _excluded2);
  var array = ArrayBase.useArray();
  var schema = useFieldSchema();
  var selected = useSelected();
  var field = array.field;
  var _useState = useState(),
    stateActiveTabKey = _useState[0],
    setStateActiveTabKey = _useState[1];
  var prefixCls = usePrefixCls('side-content', props);
  var _useStyle = useStyle(prefixCls),
    wrapSSR = _useStyle[0],
    hashId = _useStyle[1];
  var dataSource = Array.isArray(field.value) ? field.value.slice() : [];
  var onTab1Change = function onTab1Change(key) {
    setStateActiveTabKey(key);
  };
  var _useState2 = useState(takeDefaultActiveKeys(dataSource.length, (_props$defaultOpenPan = props.defaultOpenPanelCount) !== null && _props$defaultOpenPan !== void 0 ? _props$defaultOpenPan : Infinity)),
    activeKeys = _useState2[0],
    setActiveKeys = _useState2[1];
  useEffect(function () {
    if (!field.modified && dataSource.length) {
      var _props$defaultOpenPan2;
      setActiveKeys(takeDefaultActiveKeys(dataSource.length, (_props$defaultOpenPan2 = props.defaultOpenPanelCount) !== null && _props$defaultOpenPan2 !== void 0 ? _props$defaultOpenPan2 : Infinity));
    }
  }, [dataSource.length, field]);
  if (!schema) throw new Error('can not found schema object');
  var itemsSchema = Array.isArray(array.schema.items) ? array.schema.items[0] : array.schema.items;
  var _ref3 = function () {
      var schema,
        path = '';
      itemsSchema.mapProperties(function (item) {
        if (isSidePanelComponent(item)) {
          schema = item;
          path = Object.keys(item.properties)[0];
        }
      });
      return [schema, path];
    }(),
    sideSchema = _ref3[0],
    rulePath = _ref3[1];
  var definitions = selected.getStatementStateDefinitions(selected.id);
  var tabList = undefined;
  var isStateRules = definitions && !isEmpty(definitions);
  var currentTabKey = '';
  if (isStateRules) {
    var _Object$keys;
    // field.form.clearFormGraph(`${field.address}.*.${rulePath}`);
    currentTabKey = stateActiveTabKey || ((_Object$keys = Object.keys(definitions)) === null || _Object$keys === void 0 ? void 0 : _Object$keys[0]);
    rulePath = rulePath + "__state__." + currentTabKey;
    tabList = Object.entries(definitions).map(function (_ref4) {
      var key = _ref4[0],
        tab = _ref4[1];
      return {
        key: key,
        tab: tab
      };
    });
    // 构建状态 schema
    itemsSchema = new Schema(itemsSchema.toJSON());
    itemsSchema.mapProperties(function (schema) {
      if (!isSidePanelComponent(schema)) return;
      schema.mapProperties(function (childSchema) {
        var _properties, _stateSchema;
        var stateSchema = (_stateSchema = {}, _stateSchema[childSchema.name + "__state__"] = {
          type: 'object',
          properties: (_properties = {}, _properties[currentTabKey] = childSchema.toJSON(), _properties)
        }, _stateSchema);
        schema.setProperties(stateSchema);
        schema.removeProperty(childSchema.name);
      });
    });
  }
  var isRuleEmpty = dataSource.filter(function (item) {
    return get(item, rulePath);
  }).length === 0;
  var renderEmpty = function renderEmpty() {
    if (!isRuleEmpty) return;
    return /*#__PURE__*/React.createElement(_Card, {
      className: cls(prefixCls + "-item", hashId, props.className)
    }, /*#__PURE__*/React.createElement(_Empty, {
      description: "\u6682\u65E0\u6821\u9A8C\u89C4\u5219"
    }));
  };
  var fieldNames = array.field.componentProps.fieldNames || {
    label: 'label',
    value: 'value'
  };
  var renderItems = function renderItems() {
    if (isRuleEmpty) return null;
    return dataSource.map(function (item, index) {
      if (!get(item, rulePath)) return null;
      var header = get(item, fieldNames.label);
      var content = /*#__PURE__*/React.createElement(SideContentItem, {
        index: index,
        key: index,
        record: item
      }, /*#__PURE__*/React.createElement(ArrayBase.Item, {
        index: index,
        key: index,
        record: item
      }, /*#__PURE__*/React.createElement(RecursionField, {
        schema: itemsSchema,
        name: index,
        filterProperties: function filterProperties(schema) {
          if (isSidePanelComponent(schema)) {
            return true;
          }
          return false;
        }
      })));
      return /*#__PURE__*/React.createElement(_Collapse, _extends({}, props, {
        key: index,
        ghost: true,
        expandIconPosition: "end",
        activeKey: activeKeys,
        onChange: function onChange(keys) {
          setActiveKeys(toArr(keys).map(Number));
        },
        className: cls(prefixCls + "-item", prefixCls + "-collapse", props.className),
        items: [{
          key: index,
          label: header,
          children: content
        }]
      }));
    });
  };
  return wrapSSR(/*#__PURE__*/React.createElement(_Card, {
    className: cls(prefixCls, hashId),
    title: props.title,
    classNames: {
      header: prefixCls + "-drawer-header",
      body: prefixCls + "-drawer-body"
    },
    extra: /*#__PURE__*/React.createElement(CloseOutlined, {
      onClick: function onClick() {
        return setOpen(false);
      }
    }),
    tabList: tabList,
    tabProps: {
      size: 'small'
    },
    onTabChange: onTab1Change
  }, /*#__PURE__*/React.createElement(SideBaseContext.Provider, {
    value: {
      field: field,
      schema: schema,
      props: {}
    }
  }, /*#__PURE__*/React.createElement(RulePathContext.Provider, {
    value: rulePath
  }, /*#__PURE__*/React.createElement(ArrayBase, {
    onAdd: function onAdd(index) {
      setActiveKeys(insertActiveKeys(activeKeys, index));
    }
  }, renderEmpty(), renderItems(), /*#__PURE__*/React.createElement(Addition, null))))));
});
export var SideContent = observer(function (props) {
  var array = ArrayBase.useArray();
  var schema = useFieldSchema();
  var _useState3 = useState(false),
    open = _useState3[0],
    setOpen = _useState3[1];
  var slotRef = useSubSlotRef();
  var prefixCls = usePrefixCls('side-content-drawer', props);
  var _useSideDrawerStyle = useSideDrawerStyle(prefixCls),
    wrapSSR = _useSideDrawerStyle[0],
    hashId = _useSideDrawerStyle[1];
  if (!schema) throw new Error('can not found schema object');
  var itemsSchema = Array.isArray(array.schema.items) ? array.schema.items[0] : array.schema.items;
  var _props = {
    title: ''
  };
  itemsSchema.mapProperties(function (schema) {
    if (isSidePanelComponent(schema)) {
      _props = schema['x-component-props'];
    }
  });
  return wrapSSR(/*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(_Button, {
    color: "primary",
    variant: "filled",
    size: "small",
    onClick: function onClick() {
      setOpen(true);
    }
  }, _props.title), /*#__PURE__*/React.createElement(_Drawer, {
    width: 400,
    open: open,
    rootStyle: {
      position: 'absolute'
    },
    push: false,
    onClose: function onClose() {
      return setOpen(false);
    },
    getContainer: function getContainer() {
      return slotRef.current;
    },
    mask: false,
    rootClassName: cls(prefixCls, hashId),
    classNames: {
      header: prefixCls + "-drawer-header"
    }
  }, /*#__PURE__*/React.createElement(SideContentDrawerContext, _extends({
    setOpen: setOpen
  }, _props)))));
});
export var Addition = observer(function (_ref5) {
  var onClick = _ref5.onClick,
    props = _objectWithoutPropertiesLoose(_ref5, _excluded3);
  var array = ArrayBase.useArray();
  var value = array.field.value || [];
  var fieldNames = array.field.componentProps.fieldNames || {
    label: 'label',
    value: 'value'
  };
  var rulePath = useContext(RulePathContext);
  var dataSource = value.filter(function (item) {
    return item && get(item, fieldNames.label) && get(item, fieldNames.value);
  });
  var rules = value.filter(function (item) {
    return item && get(item, rulePath);
  });
  var len = rules.length;
  var items = value.reduce(function (options, item, index) {
    var label = get(item, fieldNames.label);
    if (item && get(item, fieldNames.label) && get(item, fieldNames.value) && !rules.some(function (item) {
      return get(item, fieldNames.label) === label;
    })) {
      options.push({
        label: label,
        key: index
      });
    }
    return options;
  }, []);
  if (dataSource.length === len) return null;
  var onDropdownClick = function onDropdownClick(menuInfo) {
    var key = menuInfo.key;
    set(value, key + "." + rulePath, []);
    if (onClick) {
      onClick(menuInfo);
    }
  };
  return /*#__PURE__*/React.createElement(_Dropdown, {
    menu: {
      items: items,
      onClick: onDropdownClick
    },
    trigger: ['click']
  }, /*#__PURE__*/React.createElement(_Button, _extends({
    color: "primary",
    variant: "filled"
  }, props), "\u6DFB\u52A0\u9A8C\u8BC1\u5B57\u6BB5"));
});
export var useIndex = function useIndex(index) {
  var ctx = useContext(SideItemContext);
  return ctx ? ctx.index : index;
};

==> lowcode-editor-skeleton-2.0.7.tgz: package/es/components/settings/components/array-advance-table/side-content/index.js <==
import _Drawer from "antd/es/drawer";
import _extends from "@babel/runtime/helpers/extends";
import _Button from "antd/es/button";
import { observer, useFieldSchema } from '@formily/react';
import cls from 'classnames';
import { useState } from 'react';
import useStyle from './style';
import { usePrefixCls } from '@formily/antd-v5/lib/__builtins__';
import { ArrayBase } from '@formily/antd-v5';
import { isSidePanelComponent } from '../common';
import { useSubSlotRef } from '../../../context';
import { ValidatorSetter } from '../validator-setter';
export var SideContent = observer(function (props) {
  var array = ArrayBase.useArray();
  var schema = useFieldSchema();
  var _useState = useState(false),
    open = _useState[0],
    setOpen = _useState[1];
  var slotRef = useSubSlotRef();
  var prefixCls = usePrefixCls('side-content-drawer', props);
  var _useStyle = useStyle(prefixCls),
    wrapSSR = _useStyle[0],
    hashId = _useStyle[1];
  if (!schema) throw new Error('can not found schema object');
  var itemsSchema = Array.isArray(array.schema.items) ? array.schema.items[0] : array.schema.items;
  var _props = {
    title: ''
  };
  itemsSchema.mapProperties(function (schema) {
    if (isSidePanelComponent(schema)) {
      _props = schema['x-component-props'];
    }
  });
  return wrapSSR(/*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(_Button, {
    color: "primary",
    variant: "filled",
    size: "small",
    onClick: function onClick() {
      setOpen(true);
    }
  }, _props.title), /*#__PURE__*/React.createElement(_Drawer, {
    width: 400,
    open: open,
    rootStyle: {
      position: 'absolute'
    },
    push: false,
    onClose: function onClose() {
      return setOpen(false);
    },
    getContainer: function getContainer() {
      return slotRef.current;
    },
    mask: false,
    rootClassName: cls(prefixCls, hashId),
    classNames: {
      header: prefixCls + "-drawer-header"
    }
  }, /*#__PURE__*/React.createElement(ValidatorSetter, _extends({
    setOpen: setOpen
  }, _props)))));
});
